Traceability Matrix
===================

Matrix generation and format rendering.

Generator
---------

.. module:: jamb.matrix.generator

.. autofunction:: build_test_records

.. autofunction:: build_test_id_mapping

.. autofunction:: generate_test_records_matrix

.. autofunction:: generate_full_chain_matrix

Chain Builder
-------------

.. module:: jamb.matrix.chain_builder

.. autofunction:: build_full_chain_matrix

HTML Format
-----------

.. module:: jamb.matrix.formats.html

.. autofunction:: render_test_records_html

.. autofunction:: render_full_chain_html

Markdown Format
---------------

.. module:: jamb.matrix.formats.markdown

.. autofunction:: render_test_records_markdown

.. autofunction:: render_full_chain_markdown

JSON Format
-----------

.. module:: jamb.matrix.formats.json

.. autofunction:: render_test_records_json

.. autofunction:: render_full_chain_json

CSV Format
----------

.. module:: jamb.matrix.formats.csv

.. autofunction:: render_test_records_csv

.. autofunction:: render_full_chain_csv

XLSX Format
-----------

.. module:: jamb.matrix.formats.xlsx

.. autofunction:: render_test_records_xlsx

.. autofunction:: render_full_chain_xlsx
